Welcome to **geoapps** - Open-source applications in geosciences
================================================================

<img align="right" width="50%" src="https://github.com/MiraGeoscience/geoapps/raw/develop/docs/images/index_page.png">

In short
--------

The **geoapps** project has been created by [Mira Geoscience](https://mirageoscience.com/) for the development and sharing of open-source
applications in geoscience. Users will be able to directly leverage
the powerful visualization capabilities of [Geoscience ANALYST](https://mirageoscience.com/mining-industry-software/geoscience-analyst/)
along with open-source code from the Python ecosystem.

Links
-----

- [Download the latest](https://github.com/MiraGeoscience/geoapps/archive/main.zip)
- [Getting started](https://geoapps.readthedocs.io/en/latest/content/installation.html#installation)
- [Documentation](https://geoapps.readthedocs.io/en/latest/index.html)
- [Available on PyPI](https://pypi.org/project/geoapps/)

  ```pip install geoapps```


Current sponsors:
-----------------

- [Anglo American](http://www.angloamerican.ca/)
- [Barrick](https://www.barrick.com/English/home/default.aspx)
- [BHP](https://www.bhp.com/)
- [Cameco](https://www.cameco.com/)
- [Glencore](https://www.glencore.com/)
- [Mira Geoscience](https://mirageoscience.com/)
- [Rio Tinto](https://www.riotinto.com/en)
- [Teck](https://www.teck.com/)
- [Vale](http://www.vale.com/canada/EN/Pages/default.aspx)

License
-------

**geoapps** is distributed under the terms and conditions of the [MIT License](LICENSE).


*Copyright (c) 2021 Mira Geoscience Ltd.*
